# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class LicenseInitial(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "capabilities": "list[str]",
        "finalized": "bool",
        "license": "str",
        "license_present": "bool",
        "default_topology": "Topology",
    }

    attribute_map = {
        "capabilities": "capabilities",
        "finalized": "finalized",
        "license": "license",
        "license_present": "license_present",
        "default_topology": "default_topology",
    }

    def __init__(
        self,
        capabilities=None,
        finalized=None,
        license=None,
        license_present=None,
        default_topology=None,
    ):  # noqa: E501
        """LicenseInitial - a model defined in OpenAPI"""  # noqa: E501

        self._capabilities = None
        self._finalized = None
        self._license = None
        self._license_present = None
        self._default_topology = None
        self.discriminator = None

        if capabilities is not None:
            self.capabilities = capabilities
        if finalized is not None:
            self.finalized = finalized
        if license is not None:
            self.license = license
        if license_present is not None:
            self.license_present = license_present
        if default_topology is not None:
            self.default_topology = default_topology

    @property
    def capabilities(self):
        """Gets the capabilities of this LicenseInitial.  # noqa: E501

        Features available such as eBGP, CloudWAN, Containers etc.  # noqa: E501

        :return: The capabilities of this LicenseInitial.  # noqa: E501
        :rtype: list[str]
        """
        return self._capabilities

    @capabilities.setter
    def capabilities(self, capabilities):
        """Sets the capabilities of this LicenseInitial.

        Features available such as eBGP, CloudWAN, Containers etc.  # noqa: E501

        :param capabilities: The capabilities of this LicenseInitial.  # noqa: E501
        :type: list[str]
        """

        self._capabilities = capabilities

    @property
    def finalized(self):
        """Gets the finalized of this LicenseInitial.  # noqa: E501


        :return: The finalized of this LicenseInitial.  # noqa: E501
        :rtype: bool
        """
        return self._finalized

    @finalized.setter
    def finalized(self, finalized):
        """Sets the finalized of this LicenseInitial.


        :param finalized: The finalized of this LicenseInitial.  # noqa: E501
        :type: bool
        """

        self._finalized = finalized

    @property
    def license(self):
        """Gets the license of this LicenseInitial.  # noqa: E501

        State of license, accepted, in-progress, failed  # noqa: E501

        :return: The license of this LicenseInitial.  # noqa: E501
        :rtype: str
        """
        return self._license

    @license.setter
    def license(self, license):
        """Sets the license of this LicenseInitial.

        State of license, accepted, in-progress, failed  # noqa: E501

        :param license: The license of this LicenseInitial.  # noqa: E501
        :type: str
        """

        self._license = license

    @property
    def license_present(self):
        """Gets the license_present of this LicenseInitial.  # noqa: E501


        :return: The license_present of this LicenseInitial.  # noqa: E501
        :rtype: bool
        """
        return self._license_present

    @license_present.setter
    def license_present(self, license_present):
        """Sets the license_present of this LicenseInitial.


        :param license_present: The license_present of this LicenseInitial.  # noqa: E501
        :type: bool
        """

        self._license_present = license_present

    @property
    def default_topology(self):
        """Gets the default_topology of this LicenseInitial.  # noqa: E501


        :return: The default_topology of this LicenseInitial.  # noqa: E501
        :rtype: Topology
        """
        return self._default_topology

    @default_topology.setter
    def default_topology(self, default_topology):
        """Sets the default_topology of this LicenseInitial.


        :param default_topology: The default_topology of this LicenseInitial.  # noqa: E501
        :type: Topology
        """

        self._default_topology = default_topology

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LicenseInitial):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
